from zql.src.grammar import Grammar, parse_grammar


ZQL_GRAMMAR_PATH = "zql/src/zql_grammar.tmjd"


def get_zql_grammar() -> Grammar:
    with open(ZQL_GRAMMAR_PATH, "r") as file:
        content = file.read()
        return parse_grammar(content)